<?php

/*
 * Created on 01.04.2022 - Special Style Properties
 * HomePage: https://xentr.net
 * Copyright (c) 2022 XENTR | XenForo Add-ons - Styles -  All Rights Reserved
 */

namespace XENTR\Special;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;
use XF\Db\Schema\Alter;

class Setup extends AbstractSetup
{
    use StepRunnerInstallTrait;
    use StepRunnerUpgradeTrait;
    use StepRunnerUninstallTrait;

	// Special Style Framework Install
	
	public function checkRequirements(&$errors = [], &$warnings = [])
	{
		if (\XF::$versionId < 2020870)
		{
			$errors[] = 'XenTR - Special style should be just use with the XenForo 2.2.8+';
			return $errors;
		}
		return $errors;
	}		

	public function installStep1()
	{
        $this->schemaManager()->alterTable('xf_forum', function(Alter $table)
        {
			$table->addColumn('xtr_notice', 'int')->setDefault(0);
			$table->addColumn('xtr_notice_position', 'int')->setDefault(1);
			$table->addColumn('xtr_notice_content', 'text', 1)->nullable()->setDefault('NULL');
			$table->addColumn('xtr_notice_icon', 'text', 1)->nullable()->setDefault('NULL');
			$table->addColumn('xtr_notice_icon_color', 'text', 1)->nullable()->setDefault('NULL');
			$table->addColumn('xtr_notice_bg', 'text', 1)->nullable()->setDefault('NULL');
        });
	}
	
	public function installStep2()
	{
        $this->schemaManager()->alterTable('xf_node', function(Alter $table)
        {
			$table->addColumn('xtr_node_image_enable', 'int', 3)->setDefault(0);
			$table->addColumn('xtr_node_image', 'varchar', 250)->nullable()->setDefault('NULL');
			$table->addColumn('xtr_node_color', 'varchar', 250)->nullable()->setDefault('NULL');
			$table->addColumn('xtr_node_desc_color', 'varchar', 250)->nullable()->setDefault('NULL');
        }); 
	}
	
    public function installStep3()
    {
        $this->schemaManager()->alterTable('xf_navigation', function(Alter $table)
        {
            $table->addColumn('xentr_nav_icon', 'varchar', 50)->nullable()->setDefault('');
        });
    }
	
	// Special Style Framework Upgrade
	public function upgrade(array $stepParams = [])
	{
		// TODO: Implement upgrade() method.
	}
	
	// Special Style Framework Uninstall
	public function uninstallStep1()
	{
        $this->schemaManager()->alterTable('xf_forum', function(Alter $table)
        {
			$table->dropColumns('xtr_notice');
			$table->dropColumns('xtr_notice_position');
			$table->dropColumns('xtr_notice_content');
			$table->dropColumns('xtr_notice_icon');
			$table->dropColumns('xtr_notice_icon_color');
			$table->dropColumns('xtr_notice_bg');
        });
	}

	public function uninstallStep2()
	{
        $this->schemaManager()->alterTable('xf_node', function(Alter $table)
        {
			$table->dropColumns('xtr_node_image_enable');
			$table->dropColumns('xtr_node_image');
			$table->dropColumns('xtr_node_color');
			$table->dropColumns('xtr_node_desc_color');
        });
	}
	
    public function uninstallStep3()
    {
        $this->schemaManager()->alterTable('xf_navigation', function(Alter $table)
        {
            $table->dropColumns(['xentr_nav_icon']);
        });
    }
	
	public function uninstallStep4()
	{

		\XF\Util\File::deleteAbstractedDirectory('data://assets/nodeimage');
	}
}